package cn.pluss.platform.qrCode;

import cn.pluss.platform.entity.QrCode;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;
import java.util.Map;


public interface QrCodeService extends IService<QrCode> {

    void saveQrCode(QrCode qrCode);

    void batchSaveQrCode(List<QrCode> qrCode);

    void updateQrCode(QrCode qrCode);

    List<QrCode> queryQrCodePage(Map map);

    Integer queryQrCodePageCount(Map map);

    QrCode getQrCodeByQrNo(String qrNo);

    void deleteQrCodeByIds(String[] ids);

    Integer checkQrNo(List<String> checkQrNo);
}
